@@ -43,23 +43,23 @@ static void merge_contacts_cb (GtkWidget *, gpointer);
 
 typedef struct {
   OssoABookMenuExtension parent_instance;
-} ExampleMenuExtension;
+} MergeContactsExtension;
 
 typedef struct {
   OssoABookMenuExtensionClass parent_class;
-} ExampleMenuExtensionClass;
+} MergeContactsExtensionClass;
 
 G_GNUC_INTERNAL GType
 merge_contacts_menu_extension_get_type (void) G_GNUC_CONST;
 
 /* Defines the new plugin object */
 OSSO_ABOOK_DEFINE_MENU_PLUGIN
-        (ExampleMenuExtension,
+        (MergeContactsExtension,
          merge_contacts_menu_extension,
          OSSO_ABOOK_TYPE_MENU_EXTENSION,,);
 
 static void
-merge_contacts_menu_extension_init (ExampleMenuExtension *ext)
+merge_contacts_menu_extension_init (MergeContactsExtension *ext)
 {
 }
 
@@ -481,7 +481,7 @@ get_n_menu_entries (OssoABookMenuExtension *menu_extension)
 }
 
 static void
-merge_contacts_menu_extension_class_init (ExampleMenuExtensionClass *cls)
+merge_contacts_menu_extension_class_init (MergeContactsExtensionClass *cls)
 {
   OssoABookMenuExtensionClass *menu_extension_class;
 
@@ -496,7 +496,7 @@ merge_contacts_menu_extension_class_init (ExampleMenuExtensionClass *cls)
 }
 
 static void
-merge_contacts_menu_extension_class_finalize (ExampleMenuExtensionClass *cls)
+merge_contacts_menu_extension_class_finalize (MergeContactsExtensionClass *cls)
 {
 }
 
